@@ -64,11 +64,19 @@ class PolymorphicProxySerializer(Serializer):
     *drf-spectacular* processes the serializer. In those cases you can explicitly state
     the mapping with ``{'legal': LegalPersonSerializer, ...}``, but it is then your
     responsibility to have a valid mapping.
+
+    It is also permissible to provide a callable with no parameters for ``serializers``,
+    such as a lambda that will return an appropriate list or dict when evaluated.
     """
     def __init__(
             self,
             component_name: str,
-            serializers: Union[Sequence[_SerializerType], Dict[str, _SerializerType]],
+            serializers: Union[
+                Sequence[_SerializerType],
+                Dict[str, _SerializerType],
+                Callable[[], Sequence[_SerializerType]],
+                Callable[[], Dict[str, _SerializerType]]
+            ],
             resource_type_field_name: Optional[str],
             many: Optional[bool] = None,
     ):
@@ -88,6 +96,16 @@ class PolymorphicProxySerializer(Serializer):
         instance._many = many
         return instance
 
+    @property
+    def serializers(self):
+        if callable(self._serializers):
+            self._serializers = self._serializers()
+        return self._serializers
+
+    @serializers.setter
+    def serializers(self, value):
+        self._serializers = value
+
     @property
     def data(self):
         self._trap()
@@ -120,6 +138,11 @@ class OpenApiExample(OpenApiSchemaBase):
     The example will be attached to the operation object where appropriate,
     i.e. where the given ``media_type``, ``status_code`` and modifiers match.
     Example that do not match any scenario are ignored.
+
+    - media_type will default to 'application/json' unless implicitly specified
+      through :class:`.OpenApiResponse`
+    - status_codes will default to [200, 201] unless implicitly specified
+      through :class:`.OpenApiResponse`
     """
     def __init__(
             self,
@@ -131,7 +154,7 @@ class OpenApiExample(OpenApiSchemaBase):
             request_only: bool = False,
             response_only: bool = False,
             parameter_only: Optional[Tuple[str, _ParameterLocationType]] = None,
-            media_type: str = 'application/json',
+            media_type: Optional[str] = None,
             status_codes: Optional[Sequence[Union[str, int]]] = None,
     ):
         self.name = name
@@ -143,7 +166,7 @@ class OpenApiExample(OpenApiSchemaBase):
         self.response_only = response_only
         self.parameter_only = parameter_only
         self.media_type = media_type
-        self.status_codes = list(map(str, status_codes)) if status_codes else ['200', '201']
+        self.status_codes = status_codes
 
 
 class OpenApiParameter(OpenApiSchemaBase):
@@ -221,6 +244,29 @@ class OpenApiResponse(OpenApiSchemaBase):
         self.examples = examples or []
 
 
+class OpenApiRequest(OpenApiSchemaBase):
+    """
+    Helper class to combine a request object (``Serializer``, ``OpenApiType``,
+    raw schema, etc.) together with an encoding object and/or examples.
+    Examples can alternatively be provided via :func:`@extend_schema <.extend_schema>`.
+
+    This class is especially helpful for customizing value encoding for
+    ``application/x-www-form-urlencoded`` and ``multipart/*``. The encoding parameter
+    takes a dictionary with field names as keys and encoding objects as values.
+    Refer to the `specification <https://swagger.io/specification/#encoding-object>`_
+    on how to build a valid encoding object.
+    """
+    def __init__(
+            self,
+            request: Any = None,
+            encoding: Optional[Dict[str, Dict[str, Any]]] = None,
+            examples: Optional[Sequence[OpenApiExample]] = None,
+    ):
+        self.request = request
+        self.encoding = encoding
+        self.examples = examples or []
+
+
 F = TypeVar('F', bound=Callable[..., Any])
 
 
@@ -305,7 +351,7 @@ def extend_schema(
         - basic types or instances of ``OpenApiTypes``
         - :class:`.PolymorphicProxySerializer` for signaling that the operation
           accepts a set of different types of objects.
-        - ``dict`` with media_type as keys and one of the above as values. Additionally in
+        - ``dict`` with media_type as keys and one of the above as values. Additionally, in
           this case, it is also possible to provide a raw schema dict as value.
     :param auth: replace discovered auth with explicit list of auth methods
     :param description: replaces discovered doc strings
